summaryrefslogtreecommitdiff
path: root/src/modules/m_dccallow.cpp
diff options
context:
space:
mode:
authorRobin Burchell <viroteck@viroteck.net>2012-05-30 02:54:45 -0700
committerRobin Burchell <viroteck@viroteck.net>2012-05-30 02:54:45 -0700
commita66b5a7b8f10a876970230cd087352d3bda5ef3e (patch)
tree4d459a14522ec518d9802d01c23f7d7a4fd338ec /src/modules/m_dccallow.cpp
parentcb9740f15157b2c32d4bd8ca9d43ae06f98aa963 (diff)
parent804c02174fd61143f6da5580dd0e28bd9f1bb8a8 (diff)
Merge pull request #173 from Robby-/insp20-moddesc
[2.0] Module description updates
Diffstat (limited to 'src/modules/m_dccallow.cpp')
-rw-r--r--src/modules/m_dccallow.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_dccallow.cpp b/src/modules/m_dccallow.cpp
index 495a0da5a..8c2a5f73e 100644
--- a/src/modules/m_dccallow.cpp
+++ b/src/modules/m_dccallow.cpp
@@ -25,7 +25,7 @@
#include "inspircd.h"
/* $ModDesc: Povides support for the /DCCALLOW command */
class BannedFileList
{
@@ -479,7 +479,7 @@ class ModuleDCCAllow : public Module
virtual Version GetVersion()
{
- return Version("Povides support for the /DCCALLOW command", VF_COMMON | VF_VENDOR);
+ return Version("Provides support for the /DCCALLOW command", VF_COMMON | VF_VENDOR);
}
};
@@ -25,7 +25,7 @@
#include "inspircd.h"
-/* $ModDesc: Povides support for the /DCCALLOW command */
+/* $ModDesc: Provides support for the /DCCALLOW command */
class BannedFileList
{